Crate keyword_in_file

Crate keyword_in_file 

WEBSITE READING

This code peice is used to put agruements into your terminal when running cargo, to 1: Search for the file name (txt) , 2: Search for a specific word in the file.txt

HOW IT’S USED: Cargo run file_name Word_to_seach_for
To turn off search caps sensitive you can run: $env:CAPS_SENS = “true/false”

Functions

main
reading_file
Examples